* ********************************************************************* *
*                                                                       *
*           Do Psychosocial Stimulation, Parental Distress and 			*
*			Early Childhood Education Enrollment Show Different 		*
*			Associations with Early Childhood Development Outcomes 		*
*			for Boys and Girls? Findings from a Phone Survey  			*
*			in Pakistan    												*
*																		*
*			Master do file                                      		*
*                                                                       *
* ********************************************************************* *


    /*
    ** Purpose:      		Analysis of Gallup phone survey data from Pakistan 
    ** Overview:    		Part I: Set globals for file paths and settings
							Part II: Call task-specific do-files 
    ** Last date modified:  11 Jun 2024
    */

******************************************************************** 
*
*       PART I:  Set globals for file paths and settings
*
******************************************************************** 

clear all 
set more off 

*** Set globals for file paths

global projectfolder       "C:\WBG\github\RR_PAK_2024_167\Reproducibility Package_Franchett, Hentschel, Hasan\Gender paper_reproducibility package_To share_9July" /* update with user details */


global dataWorkFolder      "$projectfolder"
global rawdata             "$dataWorkFolder/rawdata" 
global cleandata           "$dataWorkFolder/cleandata" 
global output              "$dataWorkFolder/output" 
global dofiles             "$dataWorkFolder/dofiles"

sysdir set PLUS "${dataWorkFolder}\ado"
set varabbrev on

version 17


ssc install mimrgns, replace
******************************************************************** 
*
*       PART II: - Call task-specific do-files
*
******************************************************************** 

*** Part 1: Clean data for Stata: 
*** Cleans the original survey data file

do "$dofiles/1_clean.do"

*** Part 2: Multiple Imputation: 
***	Imputes data through multiple imputation using chained equations 

do "$dofiles/2_imputation.do"

*** Part 3: Analysis:
*** Runs the analysis for the following:
    * Descriptive statistics and bivariate tests presented in Table 1
	* Regression models presented in Table 2
    * Figures 1-3 presenting marginal effects 
	* Regression models presented in Appendix Tables I and II

do "$dofiles/3_tables and figures.do"
