********************************************************************************
*																			   *
*           Do Psychosocial Stimulation, Parental Distress and 				   *
*			Early Childhood Education Enrollment Show Different 			   *
*			Associations with Early Childhood Development Outcomes 			   *
*			for Boys and Girls? Findings from a Phone Survey  				   *
*			in Pakistan  													   *
*																			   *
*     Stata .do file 1: Clean and Format data for Stata  					   *
*																			   *
********************************************************************************

************
* Clean and format Gallup phone survey data  
************

use "$rawdata/ECE Survey Data Instalment 6_original data.dta", clear

	* Generate age category variable
	gen age_cat=0 if c_age<36
	replace age_cat=1 if c_age>=36
	
	label var age_cat "Child age category"
	label define agecat 0 "0-35 mos" 1 "36-72 mos"
	label val age_cat agecat

	* Generate parental distress variables 
	gen distq1=q1_a6
	gen distq2=q2_a6
	gen distq3=q3_a6 
	gen distq4=q4_a6
	gen distq5=q5_a6

	foreach var in distq1 distq2 distq3 distq4 distq5 {
	replace `var'=. if `var'>=98
	}

	label var distq1 "Found it difficult to be affectionate to their child"
	label var distq2 "Been more irritated/angry than usual"
	label var distq3 "Found it difficult to sleep"
	label var distq4 "Was nervous or anxious"
	label var distq5 "Unable to control their worry"
	label define yn 0 "No" 1 "Yes"
	label val distq* yn
	
	egen distsum=rowtotal(distq1 distq2 distq3 distq4 distq5)
	generate nmiss_dist = missing(distq1) + missing(distq2) + missing(distq3) + missing(distq4) + missing(distq5)
	replace distsum=. if nmiss_dist>2
	label var distsum "Parental distress sum score"
	drop nmiss_dist

		* Generate parental distress z-score 
		svy linearized: mean distsum
		estat sd
		matrix m_distsum = r(mean)
		scalar scal_distsum = m_distsum[1,1]
		di scal_distsum

		matrix sd_distsum = r(sd)
		scalar scal_distsum_sd = sd_distsum[1,1]
		di scal_distsum_sd

		gen distsum_z = (distsum - scal_distsum)/scal_distsum_sd
		svy linearized: mean distsum_z
		estat sd 
		label var distsum_z "Parental distress z-score"
		
	* Generate parental education variables 
	gen ed_cat_mat=1 if q1a_a7<=2 
	replace ed_cat_mat=2 if q1a_a7>=3 
	
	label var ed_cat_mat "Maternal education"
	label define ed 1 "Less than primary" 2 "Primary or higher"
	label val ed_cat_mat ed

	gen ed_cat_pat=1 if q1_a7<=2
	replace ed_cat_pat=2 if q1_a7>=3
	
	label var ed_cat_pat "Paternal education"
	label val ed_cat_pat ed

	* Generate rural residence variable
	gen rural=0 if dem6==1
	replace rural=1 if dem6==2
	
	label var rural "Rural residence"

	* Generate psychosocial stimulation variable
	egen psych_stim=rowtotal(q1_a3 q2_a3 q3_a3 q4_a3 q5_a3 q6_a3 q7_a3 q8_a3 ///
	q9_a3 q10_a3 q11_a3 q12_a3 q13_a3 q14_a3)

	label var psych_stim "Psychosocial stimulation sum score"
	
		* Generate pyschosocial stimulation z-score
		svy linearized: mean psych_stim
		estat sd
		matrix m_psych_stim = r(mean)
		scalar scal_psych_stim = m_psych_stim[1,1]
		di scal_psych_stim

		matrix sd_psych_stim = r(sd)
		scalar scal_psych_stim_sd = sd_psych_stim[1,1]
		di scal_psych_stim_sd

		gen psych_stim_z = (psych_stim - scal_psych_stim)/scal_psych_stim_sd
		svy linearized: mean distsum_z
		estat sd 
		label var psych_stim_z "Psychosocial stimulation z-score"

	* Generate female child gender variable 
	generate c_female=0 if c_gen==1
	replace c_female=1 if c_gen==2

	label var c_female "Child Gender - Female"
	label define female 0 "Boy" 1 "Girl"
	label val c_female female

	* Generate ECE enrolment variable
	gen ece=.
	replace ece=0 if nq3_a1==4 
	replace ece=0 if nq4_a1==7 | nq4_a1==8 
	replace ece=1 if nq4_a1<7 | nq4_a1==9 | nq4_a1==98
	
	label var ece "Enrolled in ECE"

	* Generate primary school enrolment variable
	gen primary=.
	replace primary=0 if nq3_a1 ==4
	replace primary=0 if ece==1
	replace primary=1 if nq4_a1==7 | nq4_a1==8

	label var primary "Enrolled in primary school"

	* Generate virtual school attendance variable (among children enrolled)
	gen virtual=.
	replace virtual=1 if nq3_a1==2
	replace virtual=0 if nq3_a1==1 | nq3_a1==3
	
	label var virtual "Attending school virtually"

	* Generate age standardized CREDI z-score
	gen c_age2=c_age^2
	gen c_age3=c_age^3

	label var OVERALL "CREDI overall score"
	svy linearized: regress OVERALL c_age c_age2 c_age3
	predict OVERALL_HAT
	
	gen diff=OVERALL-OVERALL_HAT
	egen diff_sd=sd(diff) 
	gen credi_z= diff/diff_sd
	drop c_age2 c_age3 OVERALL_HAT diff diff_sd
	
	label var credi_z "Age standardized CREDI z-score"

	* Generate MELQO-MODEL school readiness variables 
	
		* Math knowledge and skills
		foreach var of varlist nq1 nq2 nq3 nq4 nq5a nq6 {
		gen math`var' =0
		replace math`var' =1 if `var'==1
		replace math`var' =. if `var'>=98 | `var'==.
		}
		egen mathsum=rowtotal(mathnq1 mathnq2 mathnq3 mathnq4 mathnq5a mathnq6) ///
		if age_cat==1
		generate nmiss_math = missing(mathnq1) + missing(mathnq2) + missing(mathnq3) + ///
		missing(mathnq4) + missing(mathnq5a) + missing(mathnq6) if age_cat==1
		replace mathsum=. if nmiss_math>2 & age_cat==1
		label var mathsum "Math knowledge domain score"
		drop nmiss_math
		
		* Language and literacy knowledge and skills
		foreach var of varlist nq9 nq10 nq11 nq12 nq13 nq14 nq15 nq16 nq17 nq18 {
		gen lang`var' =0
		replace lang`var' =1 if `var'==1
		replace lang`var' =. if `var'>=98 | `var'==.
		}
		egen langsum=rowtotal(langnq9 langnq10 langnq11 langnq12 langnq13 ///
		langnq14 langnq15 langnq16 langnq17 langnq18) if age_cat==1
		generate nmiss_lang=missing(langnq9) + missing(langnq10) + missing(langnq11) + missing(langnq12) + missing(		   langnq13) + missing(langnq14) + missing(langnq15) + missing(langnq16) + missing(langnq17) + missing(langnq18) 		if age_cat==1
		replace langsum=. if nmiss_lang>2 & age_cat==1
		label var langsum "Language & literacy knowledge domain score"
		drop nmiss_lang
		
		* Socio-emotional development
		foreach var of varlist nq19 nq20 nq21 nq22 nq23 nq24 nq25 nq26 nq27 {
		gen sem`var' =0
		replace sem`var' =1 if `var'==1
		replace sem`var' =. if `var'>=98 | `var'==.
		}
		egen semsum=rowtotal(semnq19 semnq20 semnq21 semnq22 semnq23 ///
		semnq24 semnq25 semnq26 semnq27) if age_cat==1
		generate nmiss_sem=missing(semnq19) + missing(semnq20) + missing(semnq21) + missing(semnq22) + missing(semnq23)		   + missing(semnq24) + missing(semnq25) + missing(semnq26) + missing(semnq27) if age_cat==1
		replace semsum=. if nmiss_sem>3 & age_cat==1
		label var semsum "Socio-emotional domain score"
		drop nmiss_sem
		
		* Overall MODEL school readiness score 
		egen schoolreadiness=rowtotal(mathsum langsum semsum) if age_cat==1
		replace schoolreadiness=. if mathsum==. | langsum==. | semsum==.
		label var schoolreadiness "School readiness overall score"

			* Generate school readiness z-score 
			svy linearized: mean schoolreadiness
			estat sd
			matrix m_schoolr = r(mean)
			scalar scal_schoolr = m_schoolr[1,1]
			di scal_schoolr

			matrix sd_schoolr = r(sd)
			scalar scal_schoolr_sd = sd_schoolr[1,1]
			di scal_schoolr_sd

			gen schoolreadiness_z = (schoolreadiness - scal_schoolr)/scal_schoolr_sd
			svy linearized: mean schoolreadiness_z
			estat sd 
			label var schoolreadiness_z "School readiness z-score"

	save "$cleandata/ECE Survey Data Instalment 6_cleaned data.dta", replace 
	