********************************************************************************
*																			   * 
*           Do Psychosocial Stimulation, Parental Distress and 				   *
*			Early Childhood Education Enrollment Show Different 			   *
*			Associations with Early Childhood Development Outcomes 			   *
*			for Boys and Girls? Findings from a Phone Survey  				   *
*			in Pakistan  													   *
*																			   *
*     Stata .do file 3: Analysis presented in tables and figures			   *
*																			   *
********************************************************************************

**********************************
/* Analysis presented in Table 1: Descriptive Statistics and bivariate 
associations for Child Development Outcomes, Risk and Protective Factor 
Variables, and Covariates with Child Gender */
**********************************
	
	use "$cleandata/ECE Survey Data Instalment 6_cleaned data.dta", clear
	
	log using "$dataWorkFolder/output/Table1.log", replace
	
* Distribution of child gender by age category
*----------------------------------------------
	svy linearized, subpop(if age_cat==0): tab c_female, col obs percent /* 0-35m */
	svy linearized, subpop(if age_cat==1): tab c_female, col obs percent  /* 36-72m */
	
* Child development outcomes
*---------------------------
* CREDI
	* Children aged 0-35 months 
	svy linearized, subpop(if age_cat==0): mean credi_z
	svy linearized, subpop(if age_cat==0 & c_female==0): mean credi_z /* boys */
	svy linearized, subpop(if age_cat==0 & c_female==1): mean credi_z /* girls */
	svy linearized, subpop(if age_cat==0): regress credi_z c_female
* School readiness
	* Children aged 36-72 months
	svy linearized, subpop(if age_cat==1): mean schoolreadiness
	svy linearized, subpop(if age_cat==1 & c_female==0): mean schoolreadiness /* boys */
	svy linearized, subpop(if age_cat==1 & c_female==1): mean schoolreadiness /* girls */	
	svy linearized, subpop(if age_cat==1): regress schoolreadiness c_female 
	
	
* Risk factor 
*------------
* Parental distress
	* Full sample 
	svy linearized: mean distsum 
	* Children aged 0-35 months 
	svy linearized, subpop(if age_cat==0): mean distsum /* overall */
	svy linearized, subpop(if age_cat==0 & c_female==0): mean distsum /* boys */
	svy linearized, subpop(if age_cat==0 & c_female==1): mean distsum /* girls */
	svy linearized: regress distsum c_female if age_cat==0
	* Children aged 36-72 months
	svy linearized, subpop(if age_cat==1): mean distsum if age_cat==1 /* overall */
	svy linearized, subpop(if age_cat==1 &  c_female==0): mean distsum /* boys */
	svy linearized, subpop(if age_cat==1 &  c_female==1): mean distsum /* girls */	
	svy linearized, subpop(if age_cat==1): regress distsum c_female 
	
* Protective factors 
*--------------------
* Psychosocial stimulation 
	* Full sample 
	svy linearized: mean psych_stim
	* Children aged 0-35 months 
	svy linearized, subpop(if age_cat==0): mean psych_stim if age_cat==0 /* overall */
	svy linearized, subpop(if age_cat==0 & c_female==0): mean psych_stim /* boys */
	svy linearized, subpop(if age_cat==0 & c_female==1): mean psych_stim /* girls */
	svy linearized: regress psych_stim c_female if age_cat==0
	* Children aged 36-72 months
	svy linearized, subpop(if age_cat==1): mean psych_stim /* overall */
	svy linearized, subpop(if age_cat==1 & c_female==0): mean psych_stim /* boys */
	svy linearized, subpop(if age_cat==1 & c_female==1): mean psych_stim /* girls */	
	svy linearized, subpop(if age_cat==1): regress psych_stim c_female 
* Enrolled in ECE 
	* Children aged 36-72 months
	svy linearized, subpop(if age_cat==1): tab c_female ece, col row obs percent 
* Virtual ECE attendance 
	* Children aged 36-72 months
	svy linearized, subpop(if age_cat==1 & ece==1): tab c_female virtual, col row obs percent 
	
* Socio-demographic characteristics 
*----------------------------------
* Primary school enrollment 
	* Children aged 36-72 months 
	svy linearized, subpop(if age_cat==1): tab c_female primary, col row obs percent 
* Virtual primary school attendance
	* Children aged 36-72 months 
	svy linearized, subpop(if age_cat==1 & primary==1): tab c_female virtual, col row obs percent 	
* Respondent caregiver gender 
	* Full sample 
	svy linearized: tab dem3
	* Children aged 0-35 months 
	svy linearized, subpop(if age_cat==0): tab c_female dem3, col row obs percent 	
	* Children aged 36-72 months
	svy linearized, subpop(if age_cat==1): tab c_female dem3, col row obs percent
* Child age 
	* Full sample 
	svy linearized: mean c_age
	* Children aged 0-35 months 
	svy linearized, subpop(if age_cat==0): mean c_age  /* overall */
	svy linearized, subpop(if age_cat==0 & c_female==0): mean c_age /* boys */
	svy linearized, subpop(if age_cat==0 & c_female==1): mean c_age  /* girls */
	svy linearized, subpop(if age_cat==0): regress c_age c_female 
	* Children aged 36-72 months
	svy linearized, subpop(if age_cat==1): mean c_age /* overall */
	svy linearized, subpop(if age_cat==1 & c_female==0): mean c_age /* boys */
	svy linearized, subpop(if age_cat==1 & c_female==1): mean c_age /* girls */	
	svy linearized, subpop(if age_cat==1): regress c_age c_female 
* Average monthly expenditure on mobile phone 
	* Full sample 
	svy linearized: mean q2a8
	* Children aged 0-35 months 
	svy linearized, subpop(if age_cat==0): mean q2a8  /* overall */
	svy linearized, subpop(if age_cat==0 & c_female==0): mean q2a8 /* boys */
	svy linearized, subpop(if age_cat==0 & c_female==01): mean q2a8 /* girls */
	svy linearized, subpop(if age_cat==0): regress q2a8 c_female 
	* Children aged 36-72 months
	svy linearized, subpop(if age_cat==1): mean q2a8 if age_cat==1 /* overall */
	svy linearized, subpop(if age_cat==1 & c_female==0): mean q2a8  /* boys */
	svy linearized, subpop(if age_cat==1 & c_female==1): mean q2a8 /* girls */
	svy linearized, subpop(if age_cat==1): regress q2a8 c_female 
* Province 
	* Full sample 
	svy linearized: tab dem4
	* Children aged  0-35 months
	svy linearized, subpop(if age_cat==0): tab c_female dem4, col row obs percent	
	* Children aged 36-72 months
	svy linearized, subpop(if age_cat==1): tab c_female dem4, col row obs percent
* Maternal education level
	* Full sample 
	svy linearized: tab ed_cat_mat
	* Children aged 0-35 months 
	svy linearized, subpop(if age_cat==0): tab c_female ed_cat_mat, col row obs percent 	
	* Children aged 36-72 months
	svy linearized, subpop(if age_cat==1): tab c_female ed_cat_mat, col row obs percent
* Paternal education level
	* Full sample 
	svy linearized: tab ed_cat_pat
	* Children aged 0-35 months 
	svy linearized, subpop(if age_cat==0): tab c_female ed_cat_pat, col row obs percent 	
	* Children aged 36-72 months
	svy linearized, subpop(if age_cat==1): tab c_female ed_cat_pat, col row obs percent
* Living in rural area 
	* Full sample 
	svy linearized: tab rural
	* Children aged 0-35 months 
	svy linearized, subpop(if age_cat==0): tab c_female rural, col row obs percent 	
	* Children aged 36-72 months
	svy linearized, subpop(if age_cat==1): tab c_female rural, col row obs percent
* Number of people in household 
	* Full sample 
	svy linearized: mean q3_a7
	* Children aged 0-35 months 
	svy linearized, subpop(if age_cat==0): mean q3_a7 /* overall */
	svy linearized, subpop(if age_cat==0 & c_female==0): mean q3_a7 /* boys */
	svy linearized, subpop(if age_cat==0 & c_female==1): mean q3_a7 /* girls */
	svy linearized, subpop(if age_cat==0): regress q3_a7 c_female 
	* Children aged 36-72 months
	svy linearized, subpop(if age_cat==1): mean q3_a7  /* overall */
	svy linearized, subpop(if age_cat==1 & c_female==0): mean q3_a7 /* boys */
	svy linearized, subpop(if age_cat==1 & c_female==1): mean q3_a7 /* girls */
	svy linearized, subpop(if age_cat==1): regress q3_a7 c_female
	
	log close 
	
**********************************
/* Analysis presented in Table 2: Multivariate linear regression models 
examining all risks and protective factors together, by age group */
**********************************
	
	log using "$dataWorkFolder/output/Table2.log", replace

* Children aged 0-35 months
*--------------------------
	use  "$cleandata/ECE Survey Data Instalment 6_cleaned data_mi_0-35m.dta", clear
		
	* Model 1: direct effects 
	mi estimate: svy linearized: regress credi_z i.c_female distsum_z psych_stim_z ///
			i.ed_cat_mat i.ed_cat_pat i.rural q3_a7 q2a8 i.dem4 c_age i.dem3 
				
	* Model 2: with interactions
	mi estimate: svy linearized: regress credi_z i.c_female##c.distsum_z ///
			i.c_female##c.psych_stim_z i.ed_cat_mat i.ed_cat_pat i.rural q3_a7 ///
			q2a8 i.dem4 c_age i.dem3 

* Children aged 36-72 months
*---------------------------
	use "$cleandata/ECE Survey Data Instalment 6_cleaned data_mi_36-72m.dta", clear
	
	* Model 1: direct effects
	mi estimate: svy linearized: regress schoolreadiness_z i.c_female distsum_z ///
			psych_stim_z i.ece i.ed_cat_mat i.ed_cat_pat i.rural q3_a7 q2a8 ///
			i.dem4 c_age i.dem3 
			 
	* Model 2: with interactions 	 
	mi estimate: svy linearized: regress schoolreadiness_z i.c_female##c.distsum_z ///
			i.c_female##c.psych_stim_z i.c_female##i.ece i.ed_cat_mat i.ed_cat_pat ///
			i.rural q3_a7 q2a8 i.dem4 c_age i.dem3  
			
	log close 
	

**********************************				
/* Figure 1: Marginal effects of parental distress on child outcomes for
   boys and girls */
**********************************	

	log using "$dataWorkFolder/output/Figures 1-3_Marginal effects.log", replace
	
* Children aged 0-35 months
*--------------------------		
	use  "$cleandata/ECE Survey Data Instalment 6_cleaned data_mi_0-35m.dta", clear
	
	* Using estimates from Table 2, Model 2
	mi estimate: svy linearized: regress credi_z i.c_female##c.distsum_z ///
			i.c_female##c.psych_stim_z i.ed_cat_mat i.ed_cat_pat i.rural q3_a7 ///
			q2a8 i.dem4 c_age i.dem3 		
				
	* Marginal means
		mimrgns, at(distsum_z=(-1(.5)1) c_female=(0 1)) cmdmargins vsquish
		
		marginsplot, scheme(sj) name(mimrgnsplot_distz_younger, replace) yscale(range(-.5 .7)) ytick(-.5(.1).7) ylab(-.5(.1).7) xtitle("Parental distress z-score") ytitle("CREDI z-score") title("Children aged 0-35 months") 
		graph save "mimrgnsplot_distz_younger" "$output/mimrgnsplot_distz_younger.gph", replace
		
	* Estimate marginal effects
		mimrgns, dydx(distsum_z) over(c_female)  cmdmargins

* Children aged 36-72 months
*---------------------------
	use "$cleandata/ECE Survey Data Instalment 6_cleaned data_mi_36-72m.dta", clear
	
	* Using estimates from Table 2, Model 2	
	mi estimate: svy linearized: regress schoolreadiness_z i.c_female##c.distsum_z ///
			i.c_female##c.psych_stim_z i.c_female##i.ece i.ed_cat_mat i.ed_cat_pat ///
			i.rural q3_a7 q2a8 i.dem4 c_age i.dem3 	
	
	* Marginal means
		mimrgns, at(distsum_z=(-1(.5)1) c_female=(0 1)) cmdmargins vsquish
		
		marginsplot, scheme(sj) name(mimrgnsplot_distz_older, replace) yscale(range(-.5 .7)) ytick(-.5(.1).7) ylab(-.5(.1).7) xtitle("Parental distress z-score") ytitle("MELQO-MODEL z-score") title("Children aged 36-72 months") 
		graph save "mimrgnsplot_distz_older" "$output/mimrgnsplot_distz_older.gph", replace
		
	* Estimate marginal effects
		mimrgns, dydx(distsum_z) over(c_female)  cmdmargins	
		
**********************************				
/* Figure 2: Marginal effects of psychosocial stimulation on child outcomes for
   boys and girls */
**********************************	

* Children aged 0-35 months
*--------------------------		
	use  "$cleandata/ECE Survey Data Instalment 6_cleaned data_mi_0-35m.dta", clear
	
	* Using estimates from Table 2, Model 2
	mi estimate: svy linearized: regress credi_z i.c_female##c.distsum_z ///
			i.c_female##c.psych_stim_z i.ed_cat_mat i.ed_cat_pat i.rural q3_a7 ///
			q2a8 i.dem4 c_age i.dem3 		
				
	* Marginal means
		mimrgns, at(psych_stim_z=(-1(.5)1) c_female=(0 1)) cmdmargins vsquish
		
		marginsplot, scheme(sj) name(mimrgnsplot_psz_younger, replace) yscale(range(-.5 .7)) ytick(-.5(.1).7) ylab(-.5(.1).7) xtitle("Psychosocial stimulation z-score") ytitle("CREDI z-score") title("Children aged 0-35 months") 
		graph save "mimrgnsplot_psz_younger" "$output/mimrgnsplot_psz_younger.gph", replace
		
	* Estimate marginal effects
		mimrgns, dydx(psych_stim_z) over(c_female)  cmdmargins

* Children aged 36-72 months
*---------------------------
	use "$cleandata/ECE Survey Data Instalment 6_cleaned data_mi_36-72m.dta", clear
	
	* Using estimates from Table 2, Model 2	
	mi estimate: svy linearized: regress schoolreadiness_z i.c_female##c.distsum_z ///
			i.c_female##c.psych_stim_z i.c_female##i.ece i.ed_cat_mat i.ed_cat_pat ///
			i.rural q3_a7 q2a8 i.dem4 c_age i.dem3 	
	
	* Marginal means
		mimrgns, at(psych_stim_z=(-1(.5)1) c_female=(0 1)) cmdmargins vsquish
		
		marginsplot, scheme(sj) name(mimrgnsplot_psz_older, replace) yscale(range(-.5 .7)) ytick(-.5(.1).7) ylab(-.5(.1).7) xtitle("Psychosocial stimulation z-score") ytitle("MELQO-MODEL z-score") title("Children aged 36-72 months") 
		graph save "mimrgnsplot_psz_older" "$output/mimrgnsplot_psz_older.gph", replace
		
	* Estimate marginal effects
		mimrgns, dydx(psych_stim_z) over(c_female)  cmdmargins	
		
**********************************				
/* Figure 3: Marginal effects of ECE enrollment on child outcomes for
   boys and girls (older cohort only) */
**********************************		

* Children aged 36-72 months
*---------------------------
	use "$cleandata/ECE Survey Data Instalment 6_cleaned data_mi_36-72m.dta", clear
	
	* Using estimates from Table 2, Model 2	
	mi estimate: svy linearized: regress schoolreadiness_z i.c_female##c.distsum_z ///
			i.c_female##c.psych_stim_z i.c_female##i.ece i.ed_cat_mat i.ed_cat_pat ///
			i.rural q3_a7 q2a8 i.dem4 c_age i.dem3 	
			
	* Marginal means
		mimrgns, at(ece=(0 1) c_female=(0 1)) cmdmargins vsquish
		
		marginsplot, scheme(sj) name(mimrgnsplot_ece, replace) yscale(range(-.5 .7)) ytick(-.5(.1).7) ylab(-.5(.1).7) xtitle("Enrollment in Early Childhood Education") ytitle("MELQO-MODEL z-score") title("Children aged 36-72 months") 
		graph save "mimrgnsplot_ece" "$output/mimrgnsplot_ece.gph", replace
		
	* Estimate marginal effects
		mimrgns, dydx(ece) over(c_female)  cmdmargins	
	
	log close 
	
**********************************				
/* Appendix, Table I. Multivariate linear regression models, run separately
   for each risk/protective factor */
**********************************		

	log using "$dataWorkFolder/output/Appendix Table I.log", replace
	
* Children aged 0-35 months
*---------------------------
	use  "$cleandata/ECE Survey Data Instalment 6_cleaned data_mi_0-35m.dta", clear

	* Parental distress 
	
		* Model 1 : direct effects 
		mi estimate: svy linearized: regress credi_z distsum_z i.c_female c_age i.dem4 q2a8 i.dem3 ///
		i.ed_cat_mat i.ed_cat_pat i.rural q3_a7
		
		* Model 2: including interaction with gender
		mi estimate: svy linearized: regress credi_z c.distsum_z##i.c_female c_age i.dem4 q2a8 i.dem3 ///
		i.ed_cat_mat i.ed_cat_pat i.rural q3_a7
	
	* Psychosocial stimulation 	

		* Model 1 : direct effects 
		mi estimate: svy linearized: regress credi_z c.psych_stim_z i.c_female c_age i.dem4 q2a8 i.dem3 ///
		i.ed_cat_mat i.ed_cat_pat i.rural q3_a7
		
		* Model 2: including interaction with gender
		mi estimate: svy linearized: regress credi_z c.psych_stim_z##i.c_female c_age i.dem4 q2a8 i.dem3 ///
		i.ed_cat_pat i.ed_cat_mat i.rural q3_a7
		
* Children aged 36-72 months
*---------------------------
	use "$cleandata/ECE Survey Data Instalment 6_cleaned data_mi_36-72m.dta", clear
	
	* Parental distress 
	
		* Model 1: direct effects 
		mi estimate: svy linearized: regress schoolreadiness_z distsum_z i.c_female c_age i.dem4 q2a8 i.dem3 ///
		i.ed_cat_pat i.ed_cat_mat i.rural q3_a7
		
		* Model 2: including interaction with gender 
		mi estimate: svy linearized: regress schoolreadiness_z c.distsum_z##i.c_female c_age i.dem4 q2a8 i.dem3 ///
		i.ed_cat_pat i.ed_cat_mat i.rural q3_a7	

	* Psychosocial stimulation 	

		* Model 1: direct effects 
		mi estimate: svy linearized: regress schoolreadiness_z psych_stim_z i.c_female c_age i.dem4 q2a8 i.dem3 ///
		i.ed_cat_pat i.ed_cat_mat i.rural q3_a7
		
		* Model 2: including interaction with gender 
		mi estimate: svy linearized: regress schoolreadiness_z c.psych_stim_z##i.c_female c_age i.dem4 q2a8 i.dem3 ///
		i.ed_cat_pat i.ed_cat_mat i.rural q3_a7	
	
	* ECE enrollment
		
		* Model 1: direct effects 
		mi estimate: svy linearized: regress schoolreadiness_z i.ece i.c_female c_age i.dem4 q2a8 i.dem3 ///
		i.ed_cat_pat i.ed_cat_mat i.rural q3_a7
		
		* Model 2: including interaction with gender 
		mi estimate: svy linearized: regress schoolreadiness_z i.ece##i.c_female c_age i.dem4 q2a8 i.dem3 ///
		i.ed_cat_pat i.ed_cat_mat i.rural q3_a7		
			
	log close 

**********************************				
/* Appendix, Table I. Multivariate linear regression models, run separately
   for each risk/protective factor */
**********************************		
	
	use "$cleandata/ECE Survey Data Instalment 6_cleaned data.dta", clear
	
	log using "$dataWorkFolder/output/Appendix Table II.log", replace
	
* Children aged 0-35 months
*--------------------------
	
	* Model 1: direct effects 
	svy linearized, subpop(if age_cat==0): regress credi_z i.c_female distsum_z ///
			psych_stim_z i.ed_cat_mat i.ed_cat_pat i.rural q3_a7 q2a8 i.dem4 ///
			c_age i.dem3 
				
	* Model 2: with interactions
	svy linearized, subpop(if age_cat==0): regress credi_z i.c_female##c.distsum_z ///
			i.c_female##c.psych_stim_z i.ed_cat_mat i.ed_cat_pat i.rural q3_a7 ///
			q2a8 i.dem4 c_age i.dem3 

* Children aged 36-72 months
*---------------------------
	
	* Model 1: direct effects
	svy linearized, subpop(if age_cat==1): regress schoolreadiness_z i.c_female ///
			distsum_z psych_stim_z i.ece i.ed_cat_mat i.ed_cat_pat i.rural ///
			q3_a7 q2a8 i.dem4 c_age i.dem3 
			 
	* Model 2: with interactions 	 
	svy linearized, subpop(if age_cat==1): regress schoolreadiness_z ///
			i.c_female##c.distsum_z i.c_female##c.psych_stim_z i.c_female##i.ece ///
			i.ed_cat_mat i.ed_cat_pat i.rural q3_a7 q2a8 i.dem4 c_age i.dem3  
		
	log close 	
		
**********************************				
/* Note: Multiple hypothesis adjustments were conducted using code from M. Anderson following procedures outlined in Anderson (2008). P values from output were entered as data and adusted sharpened q-values were generated. The code was retrieved from:

 McKenzie, D. (2021). An updated overview of multiple hypothesis testing commands in Stata. World Bank Blogs. <https://blogs.worldbank.org/en/impactevaluations/updated-overview-multiple-hypothesis-testing-commands-stata>  */
**********************************		
